@@ -50,6 +50,7 @@
 package com.openexchange.publish.microformats;
 
 import java.io.IOException;
+import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
@@ -73,6 +74,7 @@ import com.openexchange.html.HtmlService;
 import com.openexchange.java.AllocatingStringWriter;
 import com.openexchange.java.Strings;
 import com.openexchange.log.LogFactory;
+import com.openexchange.osgi.ExceptionUtils;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationDataLoaderService;
 import com.openexchange.publish.microformats.osgi.StringTranslator;
@@ -171,15 +173,18 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
             final OXMFPublicationService publisher = publishers.get(module);
             if (publisher == null) {
-                resp.getWriter().println("Don't know how to handle module " + module);
+                final PrintWriter writer = resp.getWriter();
+                writer.println("Don't know how to handle module " + module);
+                writer.flush();
                 return;
             }
             final Context ctx = contexts.getContext(Integer.parseInt(args.get(CONTEXTID)));
             final Publication publication = publisher.getPublication(ctx, args.get(SITE));
             if (publication == null || !publication.isEnabled()) {
                 resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
-                resp.getWriter().println("Don't know site " + args.get(SITE));
-
+                final PrintWriter writer = resp.getWriter();
+                writer.println("Don't know site " + args.get(SITE));
+                writer.flush();
                 return;
             }
             if (!checkProtected(publication, args, resp)) {
@@ -222,15 +227,20 @@ public class MicroformatServlet extends OnlinePublicationServlet {
                 //html = htmlService.getConformHTML(html, Charset.defaultCharset().toString());
                 html = htmlService.sanitize(html, "microformatWhitelist", false, null, null);
             }
-            resp.getWriter().write(html);
-
+            final PrintWriter writer = resp.getWriter();
+            writer.write(html);
+            writer.flush();
         } catch (final OXException x) {
             LOG.error(x.getMessage(), x);
-            resp.getWriter().println("Publishing failed. Please try again later. Exception ID: " + x.getExceptionId());
-
+            final PrintWriter writer = resp.getWriter();
+            writer.println("Publishing failed. Please try again later. Exception ID: " + x.getExceptionId());
+            writer.flush();
         } catch (final Throwable t) {
+            ExceptionUtils.handleThrowable(t);
             LOG.error(t.getMessage(), t);
-            resp.getWriter().println("Publishing failed. Please try again later.");
+            final PrintWriter writer = resp.getWriter();
+            writer.println("Publishing failed. Please try again later.");
+            writer.flush();
         }
     }
 
